polar2grid.filters.\_filter\_scene module
=========================================

.. automodule:: polar2grid.filters._filter_scene
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
